therMizer: Extends the mizer package with temperature dynamics
Source:R/therMizer-package.R
therMizer-package.RdThis is an extension package for the mizer package that contains additional features regarding the effect of temperature on organisms.
Author
Maintainer: Romain Forestier romain.forestier@utas.edu.au [copyright holder]
Authors:
Phoebe Woodworth-Jefcoats phoebe.woodworth-jefcoats@noaa.gov (ORCID) [copyright holder]