therMizer implementation of mizer's EReproAndGrowth rate function.
The assimilation term is calculated from encounter, while maintenance
metabolism is multiplied by a temperature scalar that is aggregated across
realms.
Arguments
- params
A
MizerParamsobject that has been prepared for therMizer, typically withupgradeTherParams().- t
Numeric time in the same units as the first dimension of
other_params(params)$ocean_temp. Iftfalls outside the supplied time series, the temperature series is recycled cyclically.- encounter
Numeric array of encounter rates, as returned by
getEncounter().- feeding_level
Numeric array of feeding levels, as returned by
getFeedingLevel().- ...
Additional arguments passed through by mizer's internal rate function machinery.