therMizer implementation of mizer's PredRate rate function.
It applies the encounter temperature scalar to predation mortality.
Arguments
- params
A
MizerParamsobject that has been prepared for therMizer, typically withupgradeTherParams().- n
Numeric matrix of species abundances with species in rows and size classes in columns.
- n_pp
Numeric vector giving the background resource abundance by size.
- n_other
List of abundances for any other dynamic ecosystem components.
- t
Numeric time in the same units as the first dimension of
other_params(params)$ocean_temp. Iftfalls outside the supplied time series, the temperature series is recycled cyclically.- feeding_level
Numeric array of feeding levels, as returned by
getFeedingLevel().- ...
Additional arguments passed through by mizer's internal rate function machinery.